@@ -117,7 +117,7 @@ proc FolderChange {folder msgShowProc} {
     Fdisp_HighlightCur $folder
     Flist_Visited $folder
     set exmh(folder) $folder
-    Flist_UnseenUpdate $folder
+    Flist_UnseenUpdate $folder 0
     Scan_CacheUpdate
     Ftoc_ShowSequences
     Exmh_Status $folder
@@ -331,7 +331,7 @@ proc Folder_IsShared {folder} {
 proc Folder_FindShared {} {
     global mhProfile
     if {[catch {open $mhProfile(path)/.folders_shared} in]} {
-	Exmh_Debug $in
+	Exmh_Debug Folder_FindShared $in
 	return
     }
     foreach folder [split [read $in] \n] {
@@ -339,3 +339,7 @@ proc Folder_FindShared {} {
     }
     close $in
 }
+
+# exmh-2.5 APIs
+# Folder_CheckPointShared
+# Folder_Unseen
